@@ -23,7 +23,7 @@ from .dispatch import Kuu
 @Kuu.register(InducingPoints, Kernel)
 def Kuu_kernel_inducingpoints(inducing_variable: InducingPoints, kernel: Kernel, *, jitter=0.0):
     Kzz = kernel(inducing_variable.Z)
-    Kzz += jitter * tf.eye(len(inducing_variable), dtype=Kzz.dtype)
+    Kzz += jitter * tf.eye(inducing_variable.num_inducing, dtype=Kzz.dtype)
     return Kzz
 
 
@@ -36,10 +36,12 @@ def Kuu_sqexp_multiscale(inducing_variable: Multiscale, kernel: SquaredExponenti
     )
     d = inducing_variable._cust_square_dist(Zmu, Zmu, sc)
     Kzz = kernel.variance * tf.exp(-d / 2) * tf.reduce_prod(kernel.lengthscales / sc, 2)
-    Kzz += jitter * tf.eye(len(inducing_variable), dtype=Kzz.dtype)
+    Kzz += jitter * tf.eye(inducing_variable.num_inducing, dtype=Kzz.dtype)
     return Kzz
 
 
 @Kuu.register(InducingPatches, Convolutional)
-def Kuu_conv_patch(feat, kern, jitter=0.0):
-    return kern.base_kernel.K(feat.Z) + jitter * tf.eye(len(feat), dtype=default_float())
+def Kuu_conv_patch(inducing_variable, kernel, jitter=0.0):
+    return kernel.base_kernel.K(inducing_variable.Z) + jitter * tf.eye(
+        inducing_variable.num_inducing, dtype=default_float()
+    )
